@@ -25,6 +25,8 @@ import matplotlib.colors as mcolors
 from sklearn.decomposition import PCA
 import logging
 from itertools import product
+
+from astrape.utilities.utils import rearrange_dims
 log = logging.getLogger(__name__)
 
 available_domain_types = ["points", "image", "audio"]
@@ -439,7 +441,7 @@ class BaseProject:
     def plot_data(
         self,
         domain_type : str,
-        dataformats : Optional[str] = "NHWC",
+        dataformats : Optional[str] = "NCHW",
         n_data : Optional[int] = 10
     )->None:
         r"""Visualizes the data.
@@ -449,7 +451,7 @@ class BaseProject:
             domain_type (str): The domain type the data inhabits in. e.g., "image", "points"
 
             dataformats (str, optional): The dimensions specifying the orderings of (`N`,`H`,`W`,`C`) for image data. Does nothing when domain type is not "image".
-                Default: ``NHWC``
+                Default: ``NCHW``
 
             n_data (int): Number of image samples you want to visualize. Does nothing when domain type is not "image".
                 Default: ``10``
@@ -597,9 +599,10 @@ class BaseProject:
             self._create_folder(img_dir)
             
             if len(self.dims) == 2 : # 2D, black & white
-                imgs = np.reshape(self.X, (-1, *self.dims, 1)) # (# of samples, height, width, # of channels) i.e., NHWC       
+                imgs = np.reshape(self.X, (-1, 1, *self.dims)) # (# of samples, # of channels, height, width) i.e., NCHW   
             elif len(self.dims) > 2 : # 2D, colored images
-                imgs = np.reshape(self.X, (-1, *self.dims)) # (# of samples, height, width, # of channels) i.e., NHWC
+                dims = rearrange_dims(dims=self.dims, dataformats=dataformats)
+                imgs = np.reshape(self.X, (-1, *dims)) # (# of samples, # of channels, height, width) i.e., NCHW
 
 
             sampling_idx = np.random.choice(range(imgs.shape[0]), size=n_data)
